##  Discovering and Creating IT Components
IT components that don’t provide lifecycle information are discovered and created as fact sheets in SAP LeanIX. This process helps you understand and inform tech stack standardization.
The following image illustrates how the process of discovering IT components works.
![Discovering and Creating IT Components from SBOMs](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2748896e7a441014aa97c3af2eca5719_LowRes.png)
Discovering IT Components from SBOM Components
To analyze SBOM components that you uploaded, you can use the SBOM explorer. To learn more, see [SBOM Explorer](https://help.sap.com/docs/leanix/ea/sbom-explorer?locale=en-US&state=PRODUCTION&version=CLOUD "The SBOM explorer helps you understand your open-source libraries' usage, manage them, track them during cybersecurity incidents, and quickly take action to address risks and compliance issues.").
